package com.bigflix.BigFlixMovies;

import android.app.Activity;
import android.content.res.Configuration;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.Window;
import android.widget.Button;
import android.widget.TextView;

import com.app.pokktsdk.AdConfig;
import com.app.pokktsdk.PokktManager;
import com.app.pokktsdk.enums.AdFormat;
import com.app.pokktsdk.enums.IAPStoreType;
import com.app.pokktsdk.model.InAppPurchaseDetail;
import com.pokkt.videodemo.R;

//import com.pokkt.thirdparty.ChartboostNetwork;

public class VideoActivity extends Activity {
    private Button btnPlayVideoWithIncent;
    private Button btnPlayVideoWithoutIncent;
    private Button btnStartVideoCaching;

    private Button btnInterstitialWithIncent;
    private Button btnInterstitialWithoutIncent;
    private Button btnStartInterstitialCaching;

    private boolean isIncent;
    private String screenName;
    private AdConfig videoAdConfig;
    private AdConfig interstitialAdConfig;
    private TextView screenText;
    private boolean testIAPTracker = false;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        super.onCreate(savedInstanceState);

        setContentView(R.layout.video);

        btnStartVideoCaching = (Button) findViewById(R.id.button_start_video_cache);
        btnPlayVideoWithIncent = (Button) findViewById(R.id.button_incent_video_without_cache);
        btnPlayVideoWithoutIncent = (Button) findViewById(R.id.button_non_incent_video_without_cache);

        btnStartInterstitialCaching = (Button) findViewById(R.id.button_start_interstitial_cache);
        btnInterstitialWithIncent = (Button) findViewById(R.id.button_incent_interstitial_without_cache);
        btnInterstitialWithoutIncent = (Button) findViewById(R.id.button_non_incent_interstitial_without_cache);

        screenText = (TextView) findViewById(R.id.textScreenName);
        btnStartVideoCaching.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                btnPlayVideoWithIncent.setVisibility(View.GONE);
                btnPlayVideoWithoutIncent.setVisibility(View.GONE);

                btnStartVideoCaching.setText("Caching started. Please wait!");
                PokktManager.cacheAd(VideoActivity.this, videoAdConfig);
            }
        });

        btnStartInterstitialCaching.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                btnInterstitialWithIncent.setVisibility(View.GONE);
                btnInterstitialWithoutIncent.setVisibility(View.GONE);

                PokktManager.cacheAd(VideoActivity.this, interstitialAdConfig);
            }
        });


        isIncent = getIntent().getBooleanExtra("isIncent", false);
        screenName = getIntent().getStringExtra("screenName");
        screenText.setText(screenName);

        //configure video adConfig
        videoAdConfig = new AdConfig(screenName, isIncent);
        videoAdConfig.setAdFormat(AdFormat.VIDEO);
        videoAdConfig.setShouldAllowSkip(true);
        videoAdConfig.setDefaultSkipTime(10);
        videoAdConfig.setBackButtonDisabled(true);

        //configure interstitial adConfig
        interstitialAdConfig = new AdConfig(screenName, isIncent);
        interstitialAdConfig.setAdFormat(AdFormat.INTERSTITIAL);

        if (isIncent) {
            btnPlayVideoWithIncent.setVisibility(View.VISIBLE);
            btnPlayVideoWithoutIncent.setVisibility(View.GONE);

            btnInterstitialWithIncent.setVisibility(View.VISIBLE);
            btnInterstitialWithoutIncent.setVisibility(View.GONE);
        } else {
            btnPlayVideoWithIncent.setVisibility(View.GONE);
            btnPlayVideoWithoutIncent.setVisibility(View.VISIBLE);

            btnInterstitialWithIncent.setVisibility(View.GONE);
            btnInterstitialWithoutIncent.setVisibility(View.VISIBLE);
        }

        btnPlayVideoWithIncent.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                PokktManager.checkAdAvailability(VideoActivity.this, videoAdConfig);
            }
        });

        btnPlayVideoWithoutIncent.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                PokktManager.checkAdAvailability(VideoActivity.this, videoAdConfig);
            }
        });

        btnInterstitialWithIncent.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                PokktManager.checkAdAvailability(VideoActivity.this, interstitialAdConfig);
            }
        });

        btnInterstitialWithoutIncent.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View v) {
                PokktManager.checkAdAvailability(VideoActivity.this, interstitialAdConfig);
            }
        });

        updateUI(Storage.getVideoPoints(this));

        PokktManager.setAdDelegate(new AdDelegate(this));
    }

    public void showAd(boolean isAdAvailable, AdConfig adConfig) {
        if (isAdAvailable) {
            PokktManager.showAd(VideoActivity.this, adConfig);
        }
    }

    @Override
    protected void onResume() {
        super.onResume();

    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
    }

    @Override
    public void onBackPressed() {
//		 If an interstitial is on screen, close it. Otherwise continue as normal.
//        if (ChartboostNetwork.handleChartBoostBack())
//            return;
//        else
            super.onBackPressed();
    }

    void updateUI(float points) {
        ((TextView) findViewById(R.id.points)).setText("Points earned: " + points);
        if(testIAPTracker) {// only for Pokkt ( testing  by developer)
            InAppPurchaseDetail details = new InAppPurchaseDetail();
            details.setProductId("xxx");
            details.setPrice((int) points);
            details.setCurrencyCode("INR");
            details.setDescription("COINS");
            details.setTitle("COIN");
            details.setPurchaseData(null);
            details.setPurchaseSignature(null);
            details.setPurchaseStore(IAPStoreType.NONE);
            PokktManager.trackIAP(VideoActivity.this, details);
        }
    }

    void showButtons(AdConfig config, float value, boolean isAdAvailable) {
        btnStartVideoCaching.setText("Start Video Caching");
        if (isAdAvailable) {
            if (isIncent) {
                if (config.getAdFormat() == AdFormat.VIDEO) {
                    btnPlayVideoWithIncent.setText("Show Incent Ad To Earn " + value + " (Cached)");
                    btnPlayVideoWithIncent.setVisibility(View.VISIBLE);
                    btnPlayVideoWithoutIncent.setVisibility(View.GONE);
                } else if (config.getAdFormat() == AdFormat.INTERSTITIAL) {
                    btnInterstitialWithIncent.setText("Show Incent Ad To Earn " + value + " (Cached)");
                    btnInterstitialWithIncent.setVisibility(View.VISIBLE);
                    btnInterstitialWithoutIncent.setVisibility(View.GONE);
                }
            } else {
                if (config.getAdFormat() == AdFormat.VIDEO) {
                    btnPlayVideoWithoutIncent.setText("Show Non Incent Ad To Earn 0.0 (Cached)");
                    btnPlayVideoWithIncent.setVisibility(View.GONE);
                    btnPlayVideoWithoutIncent.setVisibility(View.VISIBLE);
                } else if (config.getAdFormat() == AdFormat.INTERSTITIAL) {
                    btnInterstitialWithoutIncent.setText("Show Non Incent Ad To Earn 0.0 (Cached)");
                    btnInterstitialWithIncent.setVisibility(View.GONE);
                    btnInterstitialWithoutIncent.setVisibility(View.VISIBLE);
                }
            }
        } else {
            if (isIncent) {
                if (config.getAdFormat() == AdFormat.VIDEO) {
                    btnPlayVideoWithIncent.setVisibility(View.VISIBLE);
                    btnPlayVideoWithoutIncent.setVisibility(View.GONE);
                } else if (config.getAdFormat() == AdFormat.INTERSTITIAL) {
                    btnInterstitialWithIncent.setVisibility(View.VISIBLE);
                    btnInterstitialWithoutIncent.setVisibility(View.GONE);
                }
            } else {
                if (config.getAdFormat() == AdFormat.VIDEO) {
                    btnPlayVideoWithIncent.setVisibility(View.GONE);
                    btnPlayVideoWithoutIncent.setVisibility(View.VISIBLE);
                } else if (config.getAdFormat() == AdFormat.INTERSTITIAL) {
                    btnInterstitialWithIncent.setVisibility(View.GONE);
                    btnInterstitialWithoutIncent.setVisibility(View.VISIBLE);
                }
            }
        }
    }

    void resetButtonsText(AdConfig config) {
        if (config.getAdFormat() == AdFormat.VIDEO) {
            btnPlayVideoWithIncent.setText("Show Incent Video (Without Caching)");
            btnPlayVideoWithoutIncent.setText("Show Non-Incent Video (Without Caching))");
        }
        if (config.getAdFormat() == AdFormat.INTERSTITIAL) {
            btnInterstitialWithIncent.setText("Show Incent Interstitial (Without Caching)");
            btnInterstitialWithoutIncent.setText("Show Non-Incent Interstitial (Without Caching))");
        }
        btnStartVideoCaching.setText("Start Video Caching");
    }

    public void updatePoints(float points) {
        if (points == -1.00F) {
            // no points to be given.
        } else {
            updateUI(Storage.getVideoPoints(this));
        }
    }

    @Override
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
    }
}
